@@ -28,23 +28,23 @@ test_that("diagram_kpca is computing correctly",{
   
 })
 
-test_that("diagram_kpca can accept inputs from TDA, TDAstats and diagram_to_df",{
-  
-  skip_if_not_installed("TDA")
-  skip_if_not_installed("TDAstats")
-  
-  D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
-  D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
-  D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
-  D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1,dim = 1)
-  # expect_error(diagram_kpca(diagrams = list(D1,D1,D1,D1),dim = 1,features = 2,num_workers = 2),"embedding")
-  expect_error(diagram_kpca(diagrams = list(D1,D2,D3,D4),dim = 0,features = 2,num_workers = 2),"Inf")
-  D1 <- data.frame(dimension = 0,birth = 2,death = 3)
-  D2 <- data.frame(dimension = 0,birth = 2,death = 3.1)
-  D3 <- data.frame(dimension = 0,birth = c(2,5),death = c(3.1,6))
-  expect_s3_class(diagram_kpca(diagrams = list(D1,D2,D3),num_workers = 2),"diagram_kpca")
-  
-})
+# test_that("diagram_kpca can accept inputs from TDA, TDAstats and diagram_to_df",{
+# 
+#   skip_if_not_installed("TDA")
+#   skip_if_not_installed("TDAstats")
+# 
+#   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
+#   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
+#   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
+#   D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1,dim = 1)
+#   # expect_error(diagram_kpca(diagrams = list(D1,D1,D1,D1),dim = 1,features = 2,num_workers = 2),"embedding")
+#   expect_error(diagram_kpca(diagrams = list(D1,D2,D3,D4),dim = 0,features = 2,num_workers = 2),"Inf")
+#   D1 <- data.frame(dimension = 0,birth = 2,death = 3)
+#   D2 <- data.frame(dimension = 0,birth = 2,death = 3.1)
+#   D3 <- data.frame(dimension = 0,birth = c(2,5),death = c(3.1,6))
+#   expect_s3_class(diagram_kpca(diagrams = list(D1,D2,D3),num_workers = 2),"diagram_kpca")
+# 
+# })
 
 test_that("diagram_kpca can accept a precomputed Gram matrix",{
   
@@ -84,32 +84,31 @@ test_that("predict_diagram_kpca is computing correctly",{
   
 })
 
-test_that("predict_diagram_kpca can accept inputs from TDA, TDAstats and diagram_to_df",{
-  
-  skip_on_cran()
-  skip_if_not_installed("TDA")
-  skip_if_not_installed("TDAstats")
-  
-  D1 <- data.frame(dimension = 1,birth = 2,death = 3)
-  D2 <- data.frame(dimension = 1,birth = 2,death = 3.1)
-  D3 <- data.frame(dimension = 1,birth = c(2,5),death = c(3.1,6))
-  kpca <- diagram_kpca(diagrams = list(D1,D2,D3),features = 2,num_workers = 2,dim = 1)
-  D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
-  D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
-  D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
-  D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1)
-  expect_type(predict_diagram_kpca(new_diagrams = list(D1,D2,D3,D4),embedding = kpca,num_workers = 2),"double")
-  D1 <- data.frame(dimension = 0,birth = 2,death = 3)
-  D2 <- data.frame(dimension = 0,birth = 2,death = 3.1)
-  D3 <- data.frame(dimension = 0,birth = c(2,5),death = c(3.1,6))
-  kpca <- diagram_kpca(diagrams = list(D1,D2,D3),features = 2,num_workers = 2,dim = 0)
-  D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
-  D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
-  D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
-  D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1)
-  expect_error(predict_diagram_kpca(new_diagrams = list(D1,D2,D3,D4),embedding = kpca,num_workers = 2),"Inf")
-  
-})
+# test_that("predict_diagram_kpca can accept inputs from TDA, TDAstats and diagram_to_df",{
+# 
+#   skip_if_not_installed("TDA")
+#   skip_if_not_installed("TDAstats")
+# 
+#   D1 <- data.frame(dimension = 1,birth = 2,death = 3)
+#   D2 <- data.frame(dimension = 1,birth = 2,death = 3.1)
+#   D3 <- data.frame(dimension = 1,birth = c(2,5),death = c(3.1,6))
+#   kpca <- diagram_kpca(diagrams = list(D1,D2,D3),features = 2,num_workers = 2,dim = 1)
+#   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
+#   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
+#   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
+#   D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1)
+#   expect_type(predict_diagram_kpca(new_diagrams = list(D1,D2,D3,D4),embedding = kpca,num_workers = 2),"double")
+#   D1 <- data.frame(dimension = 0,birth = 2,death = 3)
+#   D2 <- data.frame(dimension = 0,birth = 2,death = 3.1)
+#   D3 <- data.frame(dimension = 0,birth = c(2,5),death = c(3.1,6))
+#   kpca <- diagram_kpca(diagrams = list(D1,D2,D3),features = 2,num_workers = 2,dim = 0)
+#   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
+#   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
+#   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
+#   D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1)
+#   expect_error(predict_diagram_kpca(new_diagrams = list(D1,D2,D3,D4),embedding = kpca,num_workers = 2),"Inf")
+# 
+# })
 
 test_that("predict_diagram_kpca can accept a precomputed Gram matrix",{
   
